@@ -3,7 +3,7 @@
 # Author: Natalia B. Bidart <natalia.bidart@canonical.com>
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright (C) 2009, 2011 Canonical Ltd.
+# Copyright (C) 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License version 3,
@@ -16,6 +16,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the protocol client."""
 
 import StringIO
@@ -175,10 +188,6 @@ class ClientTestCase(unittest.TestCase):
         self.called = False
         self.volume = None
 
-    def tearDown(self):
-        """Clean up."""
-        self.client = None
-
     def test_init_maxpayloadsize(self):
         """Get the value from the constant at init time."""
         self.assertEqual(self.client.max_payload_size,
@@ -856,9 +865,8 @@ class MockWebServer(object):
 class TimestampCheckerTestCase(TwistedTestCase):
     """Tests for the timestamp checker."""
 
-    @inlineCallbacks
+    @defer.inlineCallbacks
     def setUp(self):
-        """Initialize a fake webserver."""
         yield super(TimestampCheckerTestCase, self).setUp()
         self.ws = MockWebServer()
         self.addCleanup(self.ws.stop)
